@@ -5,7 +5,7 @@
  *
  *
  * Copyright (c) 1999, Alex Roberts
- * Copyright (c) 2003, Roland Stigge <stigge@antcom.de>
+ * Copyright (c) 2003, 2004, 2005, 2006 Roland Stigge <stigge@antcom.de>
  *
  * GTick is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with GTick; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -107,11 +107,7 @@ static format_t formats[] = {
 dsp_t* dsp_new(comm_t* comm) {
   dsp_t* result;
   
-  if (!(result = (dsp_t*) calloc(1, sizeof(dsp_t)))) {
-    printf("Error: Insufficient memory to create dsp object.\n");
-    exit(1);
-  }
-  
+  result = (dsp_t*) g_malloc0(sizeof(dsp_t));
   result->dspfd = -1;
   comm_server_register(comm);
   result->inter_thread_comm = comm;
@@ -223,12 +219,8 @@ static int generate_data(short* from,
   unsigned char* result;
   int i, j;
 
-  if (!(result = (unsigned char*)
-	malloc(result_size * dsp->samplesize / 8 * dsp->channels)))
-  {
-    fprintf(stderr, "Error: Couldn't allocate playback output buffer.\n");
-    return -1;
-  }
+  result = (unsigned char*)
+	  g_malloc(result_size * dsp->samplesize / 8 * dsp->channels);
 
   for (i = 0; i < result_size; i++) { /* for each output frame */
     double mixdown = 0.0; /* only needed if dsp->channels != from_channels */
@@ -316,12 +308,11 @@ int generate_sine(int samplefreq, double sinfreq, double sigdur, double fadedur,
                   short** samples)
 {
   int size = samplefreq * sigdur;
-  short* s = (short*) malloc(size * sizeof(short));
+  short* s = (short*) g_malloc(size * sizeof(short));
   int scale = -SHRT_MIN < SHRT_MAX ? -SHRT_MIN : SHRT_MAX;
   int i;
   double sample;
 
-  if (!s) return -1;
   for (i = 0; i < size; i++) {
     sample = sin((double)i / samplefreq * sinfreq * 2 * M_PI);
     if (i < samplefreq * fadedur)
@@ -375,7 +366,7 @@ int sndfile_get_samples(const char* filename,
   *rate = sfinfo.samplerate;
   *channels = sfinfo.channels ;
 
-  s = (short*) malloc(frames * sizeof(short) * sfinfo.channels);
+  s = (short*) g_malloc(frames * sizeof(short) * sfinfo.channels);
   
   while (i < frames && result != 0) {
     result = sf_readf_short(sf, &s[i * sfinfo.channels], bufsize);
@@ -397,7 +388,7 @@ int sndfile_get_samples(const char* filename,
  */
 static int init_sample(dsp_t* dsp) {
   if (!strcmp(dsp->soundname, "<default>")) {
-    dsp->frames = (short*) malloc(sizeof(tickdata));
+    dsp->frames = (short*) g_malloc(sizeof(tickdata));
     memcpy(dsp->frames, tickdata, sizeof(tickdata));
     dsp->number_of_frames = (signed int) sizeof(tickdata) / sizeof(short);
     dsp->rate_in = 44100;
@@ -481,10 +472,7 @@ static int prepare_buffers(dsp_t* dsp) {
   }
 
   /* generate secondary ticks */
-  if (!(tmp_buf = (short*) malloc(dsp->number_of_frames * sizeof(short)))) {
-    perror("malloc");
-    return -1;
-  }
+  tmp_buf = (short*) g_malloc(dsp->number_of_frames * sizeof(short));
   for (i = 0; i < dsp->number_of_frames; i++) {
     tmp_buf[i] = dsp->frames[i] / 2;
   }
@@ -591,10 +579,7 @@ int dsp_open(dsp_t* dsp) {
   if (debug && debug_todo)
     g_print ("dsp_open: fragment size = %d\n", dsp->fragmentsize);
 
-  if (!(dsp->fragment = g_malloc(dsp->fragmentsize))) {
-    perror("g_malloc");
-    return -1;
-  }
+  dsp->fragment = g_malloc(dsp->fragmentsize);
 
   /* get total number of fragments in dsp buffer */
   if (ioctl(dsp->dspfd, SNDCTL_DSP_GETOSPACE, &info) == -1) {
@@ -712,10 +697,7 @@ static void wrap_position(dsp_t* dsp, int ticklen) {
     if (dsp->cyclepos >= dsp->meter)
       dsp->cyclepos = 0;
 
-    if (!(reply = (unsigned int*) malloc(sizeof(unsigned int)))) {
-      printf("wrap_position: Out of memory.\n");
-      exit(1);
-    }
+    reply = (unsigned int*) g_malloc(sizeof(unsigned int));
     *reply = dsp->cyclepos;
     comm_server_send_response(dsp->inter_thread_comm,
 			      MESSAGE_TYPE_RESPONSE_SYNC, reply);
@@ -891,11 +873,7 @@ void dsp_main_loop(dsp_t* dsp) {
     if (get_volume) {
       double volume = dsp_get_volume(dsp);
       
-      if (!(reply = (double*) malloc (sizeof(double)))) {
-	printf("Error: "
-	       "Insufficient memory to allocate for volume reply.\n");
-	exit(1);
-      }
+      reply = (double*) g_malloc0 (sizeof(double));
       *((double*)reply) = volume;
       if (*((double*)reply) != -1) {
 	comm_server_send_response(dsp->inter_thread_comm,
