@@ -4,7 +4,7 @@
  * This file is part of GTick
  *
  * Copyright (c) 1999, Alex Roberts
- * Copyright (c) 2003, Roland Stigge <stigge@antcom.de>
+ * Copyright (c) 2003, 2004, 2005, 2006 Roland Stigge <stigge@antcom.de>
  *
  * GTick is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with GTick; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  * 
  */
 
@@ -41,7 +41,27 @@
 /* logo */
 #include "aboutlogo.xpm"
 
-void about_box(metro_t* metro)
+#define RESPONSE_LICENSE 1
+
+/*
+ * callback invoked by response signal in dialog
+ */
+static void response_cb(GtkDialog *dialog, gint response, options_t* options _U_) {
+  switch (response) {
+    case RESPONSE_LICENSE:
+      license_box();
+      break;
+    case GTK_RESPONSE_DELETE_EVENT:
+    case GTK_RESPONSE_OK:
+    case GTK_RESPONSE_CLOSE:
+      gtk_widget_destroy(GTK_WIDGET(dialog));
+      break;
+    default:
+      fprintf(stderr, "Warning: Unhandled response to dialog: %d\n", response);
+  }
+}
+
+void about_box(GtkAction *action _U_, metro_t* metro)
 {
   GtkWidget* window;
   GtkWidget* vbox;
@@ -52,9 +72,10 @@ void about_box(metro_t* metro)
   GtkStyle* style;
   GtkWidget* pixmapwidget;
 
-  window = gtk_dialog_new_with_buttons("About GTick", GTK_WINDOW(metro->window),
-      GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
-      GTK_STOCK_OK, GTK_RESPONSE_NONE,
+  window = gtk_dialog_new_with_buttons(_("About GTick"), GTK_WINDOW(metro->window),
+      GTK_DIALOG_DESTROY_WITH_PARENT,
+      _("License"), RESPONSE_LICENSE,
+      GTK_STOCK_OK, GTK_RESPONSE_OK,
       NULL);
 
   g_signal_connect(G_OBJECT(window),
@@ -79,7 +100,7 @@ void about_box(metro_t* metro)
  
   label = gtk_label_new (_(
     "Copyright (c) 1999, Alex Roberts <bse@dial.pipex.com>\n"
-    "Copyright (c) 2003, Roland Stigge <stigge@antcom.de>\n"
+    "Copyright (c) 2003, 2004, 2005, 2006 Roland Stigge <stigge@antcom.de>\n"
     /* TRANSLATORS: actually, "Andrés" with acute accent (/) */
     "Logo by Mario Andres Pagella <mapagella@fitzroy-is.com.ar>\n"
     "\n"
@@ -94,10 +115,9 @@ void about_box(metro_t* metro)
   gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
   gtk_widget_show(label);
 
-  g_signal_connect_swapped(GTK_OBJECT(window),
-                           "response",
-			   G_CALLBACK(gtk_widget_destroy),
-			   GTK_OBJECT(window));
+  g_signal_connect(G_OBJECT(window), "response",
+                   G_CALLBACK(response_cb), G_OBJECT(window));
+
   gtk_widget_show(window);
 }
 
@@ -106,7 +126,7 @@ void license_box(void) {
   GtkWidget* window = get_ok_dialog(_("GTick License"),
     _("GTick - The Metronome\n"
       "Copyright (c) 1999, Alex Roberts <bse@dial.pipex.com>\n"
-      "Copyright (c) 2003, Roland Stigge <stigge@antcom.de>\n"
+      "Copyright (c) 2003, 2004, 2005, 2006 Roland Stigge <stigge@antcom.de>\n"
       "\n"
       "This program is free software; you can redistribute it and/or\n"
       "modify it under the terms of the GNU General Public License\n"
@@ -120,13 +140,13 @@ void license_box(void) {
       "\n"
       "You should have received a copy of the GNU General Public License\n"
       "along with this program; if not, write to the Free Software\n"
-      "Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, "
+      "Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, "
       "USA."), GTK_JUSTIFY_CENTER);
 
   gtk_widget_show(window);
 }
 
-void help_shortcuts(void) {
+void help_shortcuts(GtkAction *action _U_, metro_t *metro _U_) {
   GtkWidget* window = gtk_dialog_new();
   GtkWidget* button;
   GtkWidget* table;
@@ -331,9 +351,6 @@ void help_shortcuts(void) {
                    GTK_EXPAND | GTK_FILL, 0, 10, 5);
   gtk_widget_show(label);
   
-
-
-  
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox), table, TRUE, FALSE, 0);
   gtk_widget_show(table);
 
