@@ -5,8 +5,8 @@
  * 
  *
  * Copyright (c) 1999, Alex Roberts
- * Copyright (c) 2003, Roland Stigge <stigge@antcom.de>
  * Copyright (c) 2005 Marco Tulio Gontijo e Silva <mtgontijo@yahoo.com.br>
+ * Copyright (c) 2003, 2004, 2005, 2006 Roland Stigge <stigge@antcom.de>
  *
  * GTick is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with GTick; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
  
@@ -67,7 +67,7 @@ typedef struct metro_t {
   GdkPixmap* visualtick_count_pixmap;  /* double buffering cache */
   GtkWidget* visualtick_slider;        /* subwidget */
   GdkPixmap* visualtick_slider_pixmap; /* double buffering cache */
-  GtkWidget* visualtick_menu_item;
+  GtkToggleAction* visualtick_action;
   guint visualtick_timeout_handler_id;
   struct timeval visualtick_sync_time; /* time of last sync */
   unsigned int visualtick_sync_pos;    /* position of last sync */
@@ -83,19 +83,27 @@ typedef struct metro_t {
   GtkWidget* meter_spin_button;
   	
   GtkWidget* togglebutton_label;
-  GtkWidget* tempo_name;
+  GtkWidget* speed_name;               /* ComboBox */
+
+  struct timeval lasttap;              /* Last activation of Tap button */
+
   GtkObject* speed_adjustment;
   GtkObject* volume_adjustment;
   int volume_initialized; /* do we have an initial volume from server yet? */
 
-  GtkWidget* accentframe; /* show / hide */
-  GtkWidget** accentbuttons; /* to switch on / off */
-  GtkWidget* accenttable_menu_item;
+  GtkWidget* accentframe;              /* show / hide */
+  GtkWidget** accentbuttons;           /* to switch on / off */
+  GtkToggleAction* accenttable_action;
   
+  GtkWidget* profileframe;             /* show / hide */
+  GtkToggleAction* profiles_action;
+  GtkTreeView* profiles_tree;
+
   GtkWidget* statusbar;
   guint status_context;
 
   GtkWidget* start_error; /* message to be shown on metronome start error */
+  GtkAction* start_action;
 
   options_t* options;         /* structure with all the handled rc options */
 
@@ -109,5 +117,14 @@ metro_t* metro_new(void);
 void metro_delete(metro_t* metro);
 int gui_get_meter(metro_t* metro);
 
+int set_meter(metro_t* metro, const char* option_name _U_, const char* meter);
+const char* get_meter(metro_t* metro, int n _U_, char** option_name _U_);
+int set_speed(metro_t* metro, const char* option_name _U_, const char* speed);
+const char* get_speed(metro_t* metro, int n _U_, char** option_name _U_);
+int set_accents(metro_t* metro,
+                const char* option_name _U_, const char* accents);
+const char* get_accents(metro_t* metro,
+                        int n _U_, char** option_name _U_);
+
 #endif /* METRO_H */
 
