@@ -5,7 +5,7 @@
  * 
  *
  * Copyright (c) 1999, Alex Roberts
- * Copyright (c) 2003, Roland Stigge <stigge@antcom.de>
+ * Copyright (c) 2003, 2004, 2005, 2006 Roland Stigge <stigge@antcom.de>
  *
  * GTick is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with GTick; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
  
@@ -30,6 +30,9 @@
 #include <stdlib.h>
 #include <string.h>
 
+/* GTK+ headers */
+#include <glib.h>
+
 /* own headers */
 #include "globals.h"
 #include "options.h"
@@ -41,12 +44,7 @@
 options_t* options_new(void) {
   options_t* result;
     
-  if (!(result = calloc(1, sizeof(options_t)))) {
-    fprintf(stderr,
-	    "options_new: Error allocating memory for options_t structure.\n");
-    exit(1);
-  }
-
+  result = g_malloc0(sizeof(options_t));
   result->option_list = option_list_new();
 
   return result;
