@@ -5,7 +5,7 @@
  * 
  *
  * Copyright (c) 1999, Alex Roberts
- * Copyright (c) 2003, Roland Stigge <stigge@antcom.de>
+ * Copyright (c) 2003, 2004, 2005, 2006 Roland Stigge <stigge@antcom.de>
  *
  * GTick is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with GTick; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -35,10 +35,7 @@
 int timeval_subtract(struct timeval* result,
                      struct timeval* x, struct timeval* y);
 char* stripchr(char* s, char c);
-char *get_homedir(void);
 char* get_rc_filename(void);
 void execute(char *command);
-double strtod_c(const char* s);
-char* dtostr_c(double d, int digits);
 
 #endif /* UTIL_H */
